#include "..\script_component.hpp"

/*
 * Function: dragonfly_db_fnc_hashDeleteId
 * Author: Creedcoder, J.Schmidt
 * Edit: 07.15.2024
 * Copyright © 2024 Creedcoder, J.Schmidt, All rights reserved
 *
 * Do not edit without permission!
 *
 * This work is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License.
 * To view a copy of this license, vist https://creativecommons.org/licenses/by-nc-sa/4.0/ or send a letter to Creative Commons,
 * PO Box 1866, Mountain View, CA 94042
 *
 * [Description]
 * Delete field in hash stored at key from DB.
 *
 * Arguments:
 * 0: Key <STRING> (default: "")
 * 1: Key Field <STRING> (default: "")
 *
 * Return Value:
 * N/A
 *
 * Examples:
 * [getPlayerUID player, "loadout"] call dragonfly_db_fnc_hashDeleteId (Server or Singleplayer Only)
 * [getPlayerUID player, "loadout"] remoteExecCall ["dragonfly_db_fnc_hashDeleteId", 2, false] (Multiplayer Only)
 *
 * Public: Yes
 */

params [["_key", "", [""]], ["_keyField", "", [""]]];

#ifdef __A3__DEBUG__
	diag_log text format ["ArmaDragonflyClient: 'dragonfly_db_fnc_hashDeleteId' Key: '%1', KeyField: '%2'", _key, _keyField];
#endif

if (_key == "" || _keyField == "") exitWith {
    diag_log text format ["ArmaDragonflyClient: 'dragonfly_db_fnc_hashDeleteId' Invalid Input for Key '%1' or KeyField '%2'", _key, _keyField];
};

"ArmaDragonflyClient" callExtension ["hdelid", [_key, _keyField]];