---
title: ArmaDragonflyClient - Scheduler
icon: mdi:file-text-outline
excerpt: Scheduled Environment for extension.
---

# dragonfly_db_fnc_scheduler

## Description
Manages the callback system for the ArmaDragonflyClient extension. This function receives task IDs from the extension's asynchronous callbacks, parses them, and registers them in a hashmap for later processing. It acts as the bridge between the extension's asynchronous operations and the game's execution environment.

## Syntax
```sqf
[_taskID] call dragonfly_db_fnc_scheduler
```

## Parameters
| Parameter | Type   | Description                                     | Default |
|-----------|--------|-------------------------------------------------|---------|
| `_taskID` | String | Task identifier returned from extension callback | ""      |

## Return Value
None. The function registers the task ID in a hashmap for later processing.

## Examples
### Process a callback from the extension:
```sqf
["1689524160123_get"] call dragonfly_db_fnc_scheduler;
```

### Forward a callback to the server:
```sqf
["1689524160123_hgetall"] remoteExecCall ["dragonfly_db_fnc_scheduler", 2, false];
```

## Notes
- Parses the task ID to extract the timestamp and operation type
- Registers the task in a type-specific hashmap using the mission namespace
- Each operation type (get, hgetall, etc.) has its own hashmap for tracking
- The format of task IDs is typically: `[timestamp]_[operation]`
- This function is automatically called by the extension callback mechanism
- Creates hashmaps on demand if they don't already exist
- Critical for handling asynchronous database operations

## Related Functions
- `dragonfly_db_fnc_fetch`: Assembles data chunks for large datasets
- `dragonfly_db_fnc_handler`: Processes the data retrieved from database operations
- `dragonfly_db_fnc_processQueue`: Executes queued database operations

## Links

[Add Task](addTask.md) |
[Handler](handler.md) |
[Init](init.md) |
[Print Addon Name](printAddonName.md) |
[Process Queue](processQueue.md) |
[Scheduler](scheduler.md) |
[Test](test.md)